@@ -177,6 +177,8 @@ def plot_density(sashimi_obj, pickle_filename, event):
     nxticks = settings["nxticks"]
     show_ylabel = settings["show_ylabel"]
     show_xlabel = settings["show_xlabel"]
+    print "Using intron scale ", intron_scale
+    print "Using exon scale ", exon_scale
 
     # Always show y-axis for read densities for now
     showYaxis = True
@@ -193,7 +195,7 @@ def plot_density(sashimi_obj, pickle_filename, event):
     nfiles = len(bam_files)
     suptitle(event, fontsize=10)
     plotted_axes = []
-
+    
     for i in range(nfiles):
         if colors is not None:
             color = colors[i]
@@ -209,7 +211,6 @@ def plot_density(sashimi_obj, pickle_filename, event):
             showXaxis = True 
 
         bam_file = os.path.expanduser(bam_files[i])
-        miso_file = os.path.expanduser(miso_files[i])
         ax1 = subplot2grid((nfiles + 3, gene_posterior_ratio), (i, 0),
                            colspan=gene_posterior_ratio - 1)
         
@@ -232,6 +233,7 @@ def plot_density(sashimi_obj, pickle_filename, event):
         plotted_axes.append(plotted_ax)
 
         if show_posteriors:
+            miso_file = os.path.expanduser(miso_files[i])
             try:
                 ax2 = subplot2grid((nfiles + 3, gene_posterior_ratio),\
                     (i, gene_posterior_ratio - 1))
@@ -269,6 +271,8 @@ def plot_density(sashimi_obj, pickle_filename, event):
     fake_ymin = -0.5 * max_used_yval
     universal_yticks = linspace(0, max_used_yval,
                                 nyticks + 1)
+    # Round up yticks
+    universal_ticks = map(math.ceil, universal_yticks)
     for sample_num, curr_ax in enumerate(plotted_axes):
         if showYaxis:
             curr_ax.set_ybound(lower=fake_ymin, upper=max_used_yval)
@@ -314,8 +318,9 @@ def plot_density(sashimi_obj, pickle_filename, event):
             label_ypos = universal_yticks[-2] + halfway_ypos
         else:
             label_ypos = universal_yticks[-1]
+        curr_label = settings["sample_labels"][sample_num]
         curr_ax.text(max(graphcoords), label_ypos,
-                     sample_label,
+                     curr_label,
                      fontsize=font_size,
                      va='bottom',
                      ha='right',
@@ -385,6 +390,7 @@ def readsToWiggle_pysam(reads, tx_start, tx_end):
         aligned_positions = read.positions
         for i, pos in enumerate(aligned_positions):
             if pos < tx_start or pos > tx_end:
+#                print "=>",pos
                 continue
             wig_index = pos-tx_start
             wiggle[wig_index] += 1./read.qlen
@@ -622,7 +628,8 @@ def cubic_bezier(pts, t):
 
     
 def plot_density_from_file(settings_f, pickle_filename, event,
-                           output_dir):
+                           output_dir,
+                           no_posteriors=False):
     """
     Read MISO estimates given an event name.
     """
@@ -631,20 +638,21 @@ def plot_density_from_file(settings_f, pickle_filename, event,
     ##
     tx_start, tx_end, exon_starts, exon_ends, gene_obj, mRNAs, strand, chrom = \
         parseGene(pickle_filename, event)
-    
+
+    # Override settings flag on whether to show posterior plots
+    # if --no-posteriors was given to plot.py
     sashimi_obj = Sashimi(event, output_dir,
                           event=event,
                           chrom=chrom,
-                          settings_filename=settings_f)
+                          settings_filename=settings_f,
+                          no_posteriors=no_posteriors)
     
     print "Plotting read densities and MISO estimates along event..."
     print "  - Event: %s" %(event)
     
-    # Parse user given settings
-    #settings = plot_settings.parse_plot_settings(settings_f,
-    #                                             event=event,
-    #                                             chrom=chrom)
     settings = sashimi_obj.settings
+    if no_posteriors:
+        settings["show_posteriors"] = False
     bam_files = settings['bam_files']
     miso_files = settings['miso_files']
 
